@@ -110,24 +110,27 @@ void SffView::SetScale(TScale type)
 
 void SffView::CalcScale()
 {
-		int w, h;
-		switch (m_nScaleType) 
-		{
-		case FULLSCALE:
-			m_nZoom=1;
-			canvas->SetScrollbars( 1, 1, m_nBitmapWidth, m_nBitmapHeight);
-			break;
-		case FITWIDTH:
-			frame->GetClientSize(&w, &h);
-			m_nZoom=w; m_nZoom = m_nZoom/m_nBitmapWidth;
-			canvas->SetScrollbars( 1, 1, 1, m_nBitmapHeight*m_nZoom);
-			break;
-		case FULLPAGE:
-			frame->GetClientSize(&w, &h);
-			m_nZoom=h; m_nZoom /= m_nBitmapHeight;
-			canvas->SetScrollbars( 1, 1, m_nBitmapWidth*m_nZoom, 1);
-			break;
-		}
+	int w, h;
+	switch (m_nScaleType) 
+	{
+	case FULLSCALE:
+		m_nZoom=1;
+		canvas->SetScrollbars( 1, 1, m_nBitmapWidth, m_nBitmapHeight);
+		canvas->Refresh();
+		break;
+	case FITWIDTH:
+		frame->GetClientSize(&w, &h);
+		m_nZoom=w; m_nZoom = m_nZoom/m_nBitmapWidth;
+		canvas->SetScrollbars( 1, 1, 1, (int)(m_nBitmapHeight*m_nZoom));
+		canvas->Refresh();
+		break;
+	case FULLPAGE:
+		frame->GetClientSize(&w, &h);
+		m_nZoom=h; m_nZoom /= m_nBitmapHeight;
+		canvas->SetScrollbars( 1, 1, (int)(m_nBitmapWidth*m_nZoom), 1);
+		canvas->Refresh();
+		break;
+	}
 }
 
 void SffView::OnDraw(wxDC *dc)
@@ -180,7 +183,7 @@ bool SffView::OnClose(bool deleteWindow)
   SetFrame((wxFrame *) NULL);
   
   Activate(FALSE);
-    
+  
   return TRUE;
 }
 
